/******************************
Spuzzum's Damage Number Library
===============================
     by Jeremy "Spuzzum" Gibson


  This simple little library is designed to flash little num-
bers above anything you want.


  You don't necessarily have to use this just for mobs or
anything... I designed it to be generic enough that you
define everything you want with your code... all this does is
display numbers.  That means that flicking the numbers doesn't
actually injure a mob for that amount; that's the code you
provide, because every game is different.

  To use this library, it is a simple matter of calling

  s_damage(number,"colour",trg)

  where 'number' is the amount of 'points' to display, 'colour'
is what colour you'd like the numbers to be, and 'trg' is the
mob, obj, or turf to display the numbers above.

Eg.
  s_damage(50,"red",usr)
  usr.hp -= 50


  According to Final Fantasy convention, white is used for
damage, green is used for healing, red is used for immunity,
yellow is used for resistance, and blue is used for
vulnerability.  However, you can feel free to use whatever
colour you like for whatever situation you like.  After all,
you aren't working for Squaresoft. =)


  Remember, you provide the damage code; this just shows
numbers.  So if you show 9999, that doesn't necessarily
mean you kill anyone.  You show the numbers, then do the
usr.hp -= 9999 yourself.  Or whatever you do to injure
someone in your code.  I can't stress it enough that you
need to provide your own code.


  Of course, this code is restricted to showing a number up
to and including 9999.  That doesn't necessarily mean you
can't take off more hit points than that in your code, but
if you give s_damage() more than 9999, it'll bring it down
to 9999 to be able to display it.


  Here are the allowable colours:

  - "red"
  - "blue"
  - "green"
  - "white"
  - "yellow"
  - "grey"
  - "purple"
  - "orange"

  If you want another colour, just create a copy of one of
the icon files, double-click the colour in the new .dmi file
then add the appropriate code; here's what you would need:

#define SD_[blank]_COLOUR 's_[blank]nums.dmi'

in the first portion (look for the // comment) and

if("[blank]")
  icon = SD_[blank]_COLOUR

in the portion beneath that (also look for the // comment).


  Copyright 2001 Jeremy "Spuzzum" Gibson.  Permission granted
to modify for any use, under one condition: you don't claim
the library as your own, unless you rewrite the entire thing
and use none of this code (or its icons).  Hopefully that's
not too much to ask. =)

******************************/

//If you rename any of the files in the library, change
//this part of the code to reflect it.

#define SD_GREY_COLOUR '_s_greynums.dmi'
#define SD_RED_COLOUR '_s_rednums.dmi'
#define SD_BLUE_COLOUR '_s_bluenums.dmi'
#define SD_YELLOW_COLOUR '_s_yellownums.dmi'
#define SD_WHITE_COLOUR '_s_whitenums.dmi'
#define SD_GREEN_COLOUR '_s_greennums.dmi'
#define SD_ORANGE_COLOUR '_s_orangenums.dmi'
#define SD_PURPLE_COLOUR '_s_purplenums.dmi'

//add other colours here

/*****************************/

proc/s_damage(num as num,colour as text,trg as mob|obj|turf)
	if(num > 9999)
	 num = 9999
	var/icon
	switch(colour)
		if("grey")
			icon = SD_GREY_COLOUR
		if("red")
			icon = SD_RED_COLOUR
		if("blue")
			icon = SD_BLUE_COLOUR
		if("yellow")
			icon = SD_YELLOW_COLOUR
		if("white")
			icon = SD_WHITE_COLOUR
		if("green")
			icon = SD_GREEN_COLOUR
		if("purple")
			icon = SD_PURPLE_COLOUR
		if("orange")
			icon = SD_ORANGE_COLOUR

		//add other colours here

	var/string = num2text(num)
	var/first_char
	var/second_char
	var/third_char
	var/fourth_char
	var/obj/s_damage_num/first
	var/obj/s_damage_num/second
	var/obj/s_damage_num/third
	var/obj/s_damage_num/fourth


	if(lentext(string) == 1)
		first_char = copytext(string,1,2)
		first = new

	if(lentext(string) == 2)
		second_char = copytext(string,1,2)
		second = new
		first_char = copytext(string,2,3)
		first = new

	if(lentext(string) == 3)
		third_char = copytext(string,1,2)
		third = new
		second_char = copytext(string,2,3)
		second = new
		first_char = copytext(string,3,4)
		first = new

	if(lentext(string) == 4)
		fourth_char = copytext(string,1,2)
		fourth = new
		third_char = copytext(string,2,3)
		third = new
		second_char = copytext(string,3,4)
		second = new
		first_char = copytext(string,4,5)
		first = new

	var/target
	target = trg
	if(ismob(trg) || isobj(trg))
		target = trg:loc
	if(first)
		first.loc = target
	if(second)
		second.loc = target
	if(third)
		third.loc = target
	if(fourth)
		fourth.loc = target

	if(first)
		first.icon = icon
		flick("---[first_char]",first)
	if(second)
		second.icon = icon
		flick("--[second_char]-",second)
	if(third)
		third.icon = icon
		flick("-[third_char]--",third)
	if(fourth)
		fourth.icon = icon
		flick("[fourth_char]---",fourth)

	spawn(6)
		if(first)
			del first
		if(second)
			del second
		if(third)
			del third
		if(fourth)
			del fourth


obj/s_damage_num
	layer = 5
	icon_state = ""